==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Web_Links/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Edellinen sivu");
define("_NEXT","Uusi sivu");
define("_YOURNAME","Nimesi");
define("_CATEGORY","Kategoria");

 
define("_CATEGORIES","Aihepiirit");
define("_LVOTES","nt");
define("_TOTALVOTES","ni :");
define("_LINKTITLE","Linkin otsikko");
define("_HITS","Lukukertoja");
define("_THEREARE","Tietokannassa on");
define("_NOMATCHES","Tietoja antamillasi hakuehdoilla ei lytynyt");
define("_SCOMMENTS","Kommentit");
define("_DESCRIPTION","Kuvaus");
define("_ONLYREGUSERSMODIFY","Vain rekisterityneet kyttjt voivat muokata. Ole hyv ja <a href=\"user.php\">rekisteridy tai kirjaudu</a>.");
define("_DATE","Piv");
define("_TO","Kenelle:");
define("_ADDLINK","Lis linkki");
define("_NEW","Uusi");
define("_POPULAR","Suosittu");
define("_TOPRATED","Huippuluokiteltu");
define("_RANDOM","Satunnainen");
define("_LINKSMAIN","Etusivu");
define("_LINKCOMMENTS","Linkkien kommentit");
define("_ADDITIONALDET","Listiedot");
define("_EDITORREVIEW","Toimittajan valinnat");
define("_REPORTBROKEN","Ilmoita toimimattomasta linkist");
define("_LINKSMAINCAT","Kategoriat");
define("_AND","ja");
define("_INDB","kannassamme");
define("_ADDALINK","Lis linkki");
define("_INSTRUCTIONS","Ohjeet");
define("_SUBMITONCE","Lis linkkisi vain kerran.");
define("_POSTPENDING","Linkkisi listn vasta hyvksymisen jlkeen");
define("_USERANDIP","Kyttjtunnus ja IP talletetaan, joten ethn kyt jrjestelm vrin.");
define("_PAGETITLE","Sivun otsikko");
define("_PAGEURL","Sivun URL");
define("_YOUREMAIL","Shkpostisi");
define("_LDESCRIPTION","Kuvaus: (255 merkki max)");
define("_ADDURL","Lis");
define("_LINKSNOTUSER1","Et ole rekisterity kyttj tai et ole kirjautunut sisn.");
define("_LINKSNOTUSER2","Jos olisit rekisterity kyttj, voisit list linkkej tlle sivulle.");
define("_LINKSNOTUSER3","Rekisterityminen on helppoa ja vaivatonta.");
define("_LINKSNOTUSER4","Miksi vaadimme rekisteritymist psemiseksi ksiksi tiettyihin ominaisuuksiin?");
define("_LINKSNOTUSER5","Jotta voisimme tarjota sinulle vain korkeimman laatuisen sislln,");
define("_LINKSNOTUSER6","jokainen kohta tarkastetaan ja hyvksytn yllpidossa.");
define("_LINKSNOTUSER7","Toivomme voivamme tarjota sinulle vain arvokasta tietoa.");
define("_LINKSNOTUSER8","<a href=\"user.php\">Rekisteridy</a>");
define("_LINKALREADYEXT","VIRHE: Tm osoite on jo kannassa!");
define("_LINKNOTITLE","VIRHE: Sinun tytyy kirjoittaa OTSIKKO osoitteellesi!");
define("_LINKNOURL","VIRHE: Sinun tytyy kirjoittaa URL osoitteellesi!");
define("_LINKNODESC","VIRHE: Sinun tytyy kirjoittaa KUVAUS osoitteellesi!");
define("_LINKRECEIVED","Vastaanotimme linkkiehdotuksesi. Kiitos!");
define("_EMAILWHENADD","Saat shkpostin, kun se on hyvksytty.");
define("_CHECKFORIT","Et kirjoittanut shkpostiosoitettasi. Tarkistamme kuitenkin linkkisi pian.");
define("_NEWLINKS","Uudet linkit");
define("_TOTALNEWLINKS","Kaikki uudet linkit");
define("_LASTWEEK","viime viikolta");
define("_LAST30DAYS","viimeisilt 30 pivlt");
define("_1WEEK","1 viikon ajalta");
define("_2WEEKS","2 viikon ajalta");
define("_30DAYS","30 pivn ajalta");
define("_SHOW","Nyt");
define("_TOTALFORLAST","Kaikki uudet linkit viimeisilt");
define("_DAYS","pivlt");
define("_ADDEDON","listty");
define("_RATING","Sija");
define("_RATESITE","Arvostele tt sivua");
define("_DETAILS","Yksityiskohdat");
define("_BESTRATED","Parhaiten arvostellut linkit - Top");
define("_OF","of");
define("_TRATEDLINKS","kaikki arvostellut linkit");
define("_TVOTESREQ","nten mrn minimi");
define("_SHOWTOP","Nyt Top");
define("_MOSTPOPULAR","Suosituimmat - Top");
define("_OFALL","kaikista");
define("_SORTLINKSBY","Lajittele");
define("_SITESSORTED","Tll hetkell lajiteltu");
define("_POPULARITY","Suosio");
define("_SELECTPAGE","Valitse sivu");
define("_MAIN","Etusivu");
define("_NEWTODAY","Uusia tnn");
define("_NEWLAST3DAYS","Uudet viimeisten 3 pivn ajalta");
define("_NEWTHISWEEK","Uudet tlt viikolta");
define("_CATNEWTODAY","Uudet tnn listyt linkit tss kategoriassa");
define("_CATLAST3DAYS","Uudet viimeisten 3 pivn aikana listyt linkit tss kategoriassa");
define("_CATTHISWEEK","Uudet tmn viikon aikana listyt linkit tss kategoriassa");
define("_POPULARITY1","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_POPULARITY2","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_TITLEAZ","Otsikko (A - Z)");
define("_TITLEZA","Otsikko (Z - A)");
define("_DATE1","Pivys (Vanhat ensin)");
define("_DATE2","Pivys (Uudet ensin)");
define("_RATING1","Tila (Viimeisest ensimmiseen)");
define("_RATING2","Tila (Ensimmisest viimeiseen)");
define("_SEARCHRESULTS4","Hakutulokset");
define("_USUBCATEGORIES","Alakategoriat");
define("_LINKS","Linkit");
define("_TRY2SEARCH","Yrit etsi");
define("_INOTHERSENGINES","muilla hakukoneilla");
define("_EDITORIAL","Kommentti");
define("_LINKPROFILE","Linkin profiili");
define("_EDITORIALBY","Kommentoinut:");
define("_NOEDITORIAL","Tlle sivulle ei tll hetkell ole kommenttia.");
define("_VISITTHISSITE","Ky tll sivulla");
define("_RATETHISSITE","Arvostele tt lhdett");
define("_ISTHISYOURSITE","Onko tm lhteesi?");
define("_ALLOWTORATE","Anna muiden kyttjien arvostella sit omalta sivultasi!");
define("_LINKRATINGDET","Linkin sijan tiedot");
define("_OVERALLRATING","Yleisarvostelu");
define("_TOTALOF","Yhteens");
define("_USER","Kyttj");
define("_USERAVGRATING","Kyttjn keskimrinen sija");
define("_NUMRATINGS","nien mr");
define("_EDITTHISLINK","Muokkaa tt linkki");
define("_REGISTEREDUSERS","Rekisterityneet kyttjt");
define("_NUMBEROFRATINGS","nien mr");
define("_NOREGUSERSVOTES","Ei rekisterityneiden kyttjien ni");
define("_BREAKDOWNBYVAL","Sijoituksien erittely arvostelun mukaan");
define("_LTOTALVOTES","yhteens ni");
define("_LINKRATING","Linkkien sijoitukset");
define("_HIGHRATING","Korkea sija");
define("_LOWRATING","Huono sija");
define("_NUMOFCOMMENTS","Kommenttien mr");
define("_WEIGHNOTE","* Huom: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien kyttjien arvostelut");
define("_NOUNREGUSERSVOTES","Ei rekisteritymttmien kyttjien ni");
define("_WEIGHOUTNOTE","* Huom.: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien nestjien arvostelut");
define("_NOOUTSIDEVOTES","Ei ulkopuolisten ni");
define("_OUTSIDEVOTERS","Ulkopuoliset nestjt");
define("_UNREGISTEREDUSERS","Rekisteritymttmt kyttjt");
define("_PROMOTEYOURSITE","Mainosta sivuasi");
define("_PROMOTE01","Voit ehk olla kiinnostunut etisist 'Arvostele sivua' vaihtoehdoistamme. Ne antavat sinulle mahdollisuuden laittaa kuvan (tai jopa arvostelun) sivullesi kasvattamaan lhteesi nien mr. Valitse yhdest alla listatuista vaihtosehdoista:");
define("_TEXTLINK","Tekstilinkki");
define("_PROMOTE02","Yksi tapa linkitt arvostelukaavakkeeseen on yksinkertainen tekstilinkki:");
define("_HTMLCODE1","HTML-koodi, jota sinun tulisi tss tapauksessa kytt, on seuraava:");
define("_THENUMBER","Mr");
define("_IDREFER","HTML-lhdekoodissa viitataan sivusi tunnusnumeroon $sivunimi -tietokannassa. Varmista ett tm numero on mainittu.");
define("_BUTTONLINK","Nappilinkki");
define("_PROMOTE03","Jos etsit jotain muuta kuin tekstilinkki, saatat haluta kytt pient nappilinkki:");
define("_RATEIT","Arvostele tt sivua!");
define("_HTMLCODE2","Lhdekoodi edell mainitulle napille on:");
define("_REMOTEFORM","Ethallittu arvostelulomake");
define("_PROMOTE04","Jos huijaat tss, poistamme linkkisi. Tlt nytt nykyinen ethallittu arvostelulomake.");
define("_VOTE4THISSITE","nest tt sivua!");
define("_LINKVOTE","nest!");
define("_HTMLCODE3","Kytten tt lomaketta kyttjt voivat arvostella sivuasi suoraan sivultasi ja arvostelu talletetaan tnne. Ylloleva lomake ei toimi, mutta seuraava lhdekoodi toimii jos yksinkertaisesti leikkaat ja liimaat sen nettisivuusi. Lhdekoodi nkyy alla:");
define("_PROMOTE05","Kiitos! ja onnea arvosteluillesi!");
define("_STAFF","Yllpito");
define("_THANKSBROKEN","Kiitos ett autoit pitmn yll tmn luettelon kokonaisuutta.");
define("_THANKSFORINFO","Kiitos tiedoista.");
define("_LOOKTOREQUEST","Tarkistamme toiveesi pian.");
define("_REQUESTLINKMOD","Esit muutos linkkeihin");
define("_LINKID","Linkin tunnus");
define("_SENDREQUEST","Lhet ehdotus");
define("_THANKSTOTAKETIME","Kiitos ajan kytstsi sivun arvosteluun tll");
define("_LETSDECIDE","Kyttjien, kuten sinun, mielipiteet auttavat muita vierailijoita paremmin pttmn mist linkist painaa.");
define("_RETURNTO","Palaa");
define("_RATENOTE1","l nest samaa lhdett enemp kuin kerran.");
define("_RATENOTE2","Asteikko on 1 - 10, jossa 1 on huono ja 10 erinomainen.");
define("_RATENOTE3","Ole puolueeton nestyksesssi, jos kaikki saavat 1 tai 10, arvosteluista ei ole paljonkaan hyty.");
define("_RATENOTE4","Voit katsoa listaa <a href=\"links.php?op=TopRated\">Parhaan arvosanan saaneista lhteist</a>.");
define("_RATENOTE5","l nest oman tai kilpailijasi lhteest.");
define("_YOUAREREGGED","Olet rekisterity kyttj ja olet kirjautunut sisn.");
define("_FEELFREE2ADD","Laita vapaasti kommentti tlle sivulle.");
define("_YOUARENOTREGGED","Et ole rekisterity kyttj tai et ole kirjautunut sisn.");
define("_IFYOUWEREREG","Jos olisit rekisteritynyt, voisit kommetoida tt sivua.");
define("_WEBLINKS","Linkit");
define("_TITLE","Otsikko");
define("_MODIFY","Muokkaa");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Web_Links/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Edellinen sivu");
define("_NEXT","Uusi sivu");
define("_YOURNAME","Nimesi");
define("_CATEGORY","Kategoria");

 
define("_CATEGORIES","Aihepiirit");
define("_LVOTES","nt");
define("_TOTALVOTES","ni :");
define("_LINKTITLE","Linkin otsikko");
define("_HITS","Lukukertoja");
define("_THEREARE","Tietokannassa on");
define("_NOMATCHES","Tietoja antamillasi hakuehdoilla ei lytynyt");
define("_SCOMMENTS","Kommentit");
define("_DESCRIPTION","Kuvaus");
define("_ONLYREGUSERSMODIFY","Vain rekisterityneet kyttjt voivat muokata. Ole hyv ja <a href=\"user.php\">rekisteridy tai kirjaudu</a>.");
define("_DATE","Piv");
define("_TO","Kenelle:");
define("_ADDLINK","Lis linkki");
define("_NEW","Uusi");
define("_POPULAR","Suosittu");
define("_TOPRATED","Huippuluokiteltu");
define("_RANDOM","Satunnainen");
define("_LINKSMAIN","Etusivu");
define("_LINKCOMMENTS","Linkkien kommentit");
define("_ADDITIONALDET","Listiedot");
define("_EDITORREVIEW","Toimittajan valinnat");
define("_REPORTBROKEN","Ilmoita toimimattomasta linkist");
define("_LINKSMAINCAT","Kategoriat");
define("_AND","ja");
define("_INDB","kannassamme");
define("_ADDALINK","Lis linkki");
define("_INSTRUCTIONS","Ohjeet");
define("_SUBMITONCE","Lis linkkisi vain kerran.");
define("_POSTPENDING","Linkkisi listn vasta hyvksymisen jlkeen");
define("_USERANDIP","Kyttjtunnus ja IP talletetaan, joten ethn kyt jrjestelm vrin.");
define("_PAGETITLE","Sivun otsikko");
define("_PAGEURL","Sivun URL");
define("_YOUREMAIL","Shkpostisi");
define("_LDESCRIPTION","Kuvaus: (255 merkki max)");
define("_ADDURL","Lis");
define("_LINKSNOTUSER1","Et ole rekisterity kyttj tai et ole kirjautunut sisn.");
define("_LINKSNOTUSER2","Jos olisit rekisterity kyttj, voisit list linkkej tlle sivulle.");
define("_LINKSNOTUSER3","Rekisterityminen on helppoa ja vaivatonta.");
define("_LINKSNOTUSER4","Miksi vaadimme rekisteritymist psemiseksi ksiksi tiettyihin ominaisuuksiin?");
define("_LINKSNOTUSER5","Jotta voisimme tarjota sinulle vain korkeimman laatuisen sislln,");
define("_LINKSNOTUSER6","jokainen kohta tarkastetaan ja hyvksytn yllpidossa.");
define("_LINKSNOTUSER7","Toivomme voivamme tarjota sinulle vain arvokasta tietoa.");
define("_LINKSNOTUSER8","<a href=\"user.php\">Rekisteridy</a>");
define("_LINKALREADYEXT","VIRHE: Tm osoite on jo kannassa!");
define("_LINKNOTITLE","VIRHE: Sinun tytyy kirjoittaa OTSIKKO osoitteellesi!");
define("_LINKNOURL","VIRHE: Sinun tytyy kirjoittaa URL osoitteellesi!");
define("_LINKNODESC","VIRHE: Sinun tytyy kirjoittaa KUVAUS osoitteellesi!");
define("_LINKRECEIVED","Vastaanotimme linkkiehdotuksesi. Kiitos!");
define("_EMAILWHENADD","Saat shkpostin, kun se on hyvksytty.");
define("_CHECKFORIT","Et kirjoittanut shkpostiosoitettasi. Tarkistamme kuitenkin linkkisi pian.");
define("_NEWLINKS","Uudet linkit");
define("_TOTALNEWLINKS","Kaikki uudet linkit");
define("_LASTWEEK","viime viikolta");
define("_LAST30DAYS","viimeisilt 30 pivlt");
define("_1WEEK","1 viikon ajalta");
define("_2WEEKS","2 viikon ajalta");
define("_30DAYS","30 pivn ajalta");
define("_SHOW","Nyt");
define("_TOTALFORLAST","Kaikki uudet linkit viimeisilt");
define("_DAYS","pivlt");
define("_ADDEDON","listty");
define("_RATING","Sija");
define("_RATESITE","Arvostele tt sivua");
define("_DETAILS","Yksityiskohdat");
define("_BESTRATED","Parhaiten arvostellut linkit - Top");
define("_OF","of");
define("_TRATEDLINKS","kaikki arvostellut linkit");
define("_TVOTESREQ","nten mrn minimi");
define("_SHOWTOP","Nyt Top");
define("_MOSTPOPULAR","Suosituimmat - Top");
define("_OFALL","kaikista");
define("_SORTLINKSBY","Lajittele");
define("_SITESSORTED","Tll hetkell lajiteltu");
define("_POPULARITY","Suosio");
define("_SELECTPAGE","Valitse sivu");
define("_MAIN","Etusivu");
define("_NEWTODAY","Uusia tnn");
define("_NEWLAST3DAYS","Uudet viimeisten 3 pivn ajalta");
define("_NEWTHISWEEK","Uudet tlt viikolta");
define("_CATNEWTODAY","Uudet tnn listyt linkit tss kategoriassa");
define("_CATLAST3DAYS","Uudet viimeisten 3 pivn aikana listyt linkit tss kategoriassa");
define("_CATTHISWEEK","Uudet tmn viikon aikana listyt linkit tss kategoriassa");
define("_POPULARITY1","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_POPULARITY2","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_TITLEAZ","Otsikko (A - Z)");
define("_TITLEZA","Otsikko (Z - A)");
define("_DATE1","Pivys (Vanhat ensin)");
define("_DATE2","Pivys (Uudet ensin)");
define("_RATING1","Tila (Viimeisest ensimmiseen)");
define("_RATING2","Tila (Ensimmisest viimeiseen)");
define("_SEARCHRESULTS4","Hakutulokset");
define("_USUBCATEGORIES","Alakategoriat");
define("_LINKS","Linkit");
define("_TRY2SEARCH","Yrit etsi");
define("_INOTHERSENGINES","muilla hakukoneilla");
define("_EDITORIAL","Kommentti");
define("_LINKPROFILE","Linkin profiili");
define("_EDITORIALBY","Kommentoinut:");
define("_NOEDITORIAL","Tlle sivulle ei tll hetkell ole kommenttia.");
define("_VISITTHISSITE","Ky tll sivulla");
define("_RATETHISSITE","Arvostele tt lhdett");
define("_ISTHISYOURSITE","Onko tm lhteesi?");
define("_ALLOWTORATE","Anna muiden kyttjien arvostella sit omalta sivultasi!");
define("_LINKRATINGDET","Linkin sijan tiedot");
define("_OVERALLRATING","Yleisarvostelu");
define("_TOTALOF","Yhteens");
define("_USER","Kyttj");
define("_USERAVGRATING","Kyttjn keskimrinen sija");
define("_NUMRATINGS","nien mr");
define("_EDITTHISLINK","Muokkaa tt linkki");
define("_REGISTEREDUSERS","Rekisterityneet kyttjt");
define("_NUMBEROFRATINGS","nien mr");
define("_NOREGUSERSVOTES","Ei rekisterityneiden kyttjien ni");
define("_BREAKDOWNBYVAL","Sijoituksien erittely arvostelun mukaan");
define("_LTOTALVOTES","yhteens ni");
define("_LINKRATING","Linkkien sijoitukset");
define("_HIGHRATING","Korkea sija");
define("_LOWRATING","Huono sija");
define("_NUMOFCOMMENTS","Kommenttien mr");
define("_WEIGHNOTE","* Huom: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien kyttjien arvostelut");
define("_NOUNREGUSERSVOTES","Ei rekisteritymttmien kyttjien ni");
define("_WEIGHOUTNOTE","* Huom.: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien nestjien arvostelut");
define("_NOOUTSIDEVOTES","Ei ulkopuolisten ni");
define("_OUTSIDEVOTERS","Ulkopuoliset nestjt");
define("_UNREGISTEREDUSERS","Rekisteritymttmt kyttjt");
define("_PROMOTEYOURSITE","Mainosta sivuasi");
define("_PROMOTE01","Voit ehk olla kiinnostunut etisist 'Arvostele sivua' vaihtoehdoistamme. Ne antavat sinulle mahdollisuuden laittaa kuvan (tai jopa arvostelun) sivullesi kasvattamaan lhteesi nien mr. Valitse yhdest alla listatuista vaihtosehdoista:");
define("_TEXTLINK","Tekstilinkki");
define("_PROMOTE02","Yksi tapa linkitt arvostelukaavakkeeseen on yksinkertainen tekstilinkki:");
define("_HTMLCODE1","HTML-koodi, jota sinun tulisi tss tapauksessa kytt, on seuraava:");
define("_THENUMBER","Mr");
define("_IDREFER","HTML-lhdekoodissa viitataan sivusi tunnusnumeroon $sivunimi -tietokannassa. Varmista ett tm numero on mainittu.");
define("_BUTTONLINK","Nappilinkki");
define("_PROMOTE03","Jos etsit jotain muuta kuin tekstilinkki, saatat haluta kytt pient nappilinkki:");
define("_RATEIT","Arvostele tt sivua!");
define("_HTMLCODE2","Lhdekoodi edell mainitulle napille on:");
define("_REMOTEFORM","Ethallittu arvostelulomake");
define("_PROMOTE04","Jos huijaat tss, poistamme linkkisi. Tlt nytt nykyinen ethallittu arvostelulomake.");
define("_VOTE4THISSITE","nest tt sivua!");
define("_LINKVOTE","nest!");
define("_HTMLCODE3","Kytten tt lomaketta kyttjt voivat arvostella sivuasi suoraan sivultasi ja arvostelu talletetaan tnne. Ylloleva lomake ei toimi, mutta seuraava lhdekoodi toimii jos yksinkertaisesti leikkaat ja liimaat sen nettisivuusi. Lhdekoodi nkyy alla:");
define("_PROMOTE05","Kiitos! ja onnea arvosteluillesi!");
define("_STAFF","Yllpito");
define("_THANKSBROKEN","Kiitos ett autoit pitmn yll tmn luettelon kokonaisuutta.");
define("_THANKSFORINFO","Kiitos tiedoista.");
define("_LOOKTOREQUEST","Tarkistamme toiveesi pian.");
define("_REQUESTLINKMOD","Esit muutos linkkeihin");
define("_LINKID","Linkin tunnus");
define("_SENDREQUEST","Lhet ehdotus");
define("_THANKSTOTAKETIME","Kiitos ajan kytstsi sivun arvosteluun tll");
define("_LETSDECIDE","Kyttjien, kuten sinun, mielipiteet auttavat muita vierailijoita paremmin pttmn mist linkist painaa.");
define("_RETURNTO","Palaa");
define("_RATENOTE1","l nest samaa lhdett enemp kuin kerran.");
define("_RATENOTE2","Asteikko on 1 - 10, jossa 1 on huono ja 10 erinomainen.");
define("_RATENOTE3","Ole puolueeton nestyksesssi, jos kaikki saavat 1 tai 10, arvosteluista ei ole paljonkaan hyty.");
define("_RATENOTE4","Voit katsoa listaa <a href=\"links.php?op=TopRated\">Parhaan arvosanan saaneista lhteist</a>.");
define("_RATENOTE5","l nest oman tai kilpailijasi lhteest.");
define("_YOUAREREGGED","Olet rekisterity kyttj ja olet kirjautunut sisn.");
define("_FEELFREE2ADD","Laita vapaasti kommentti tlle sivulle.");
define("_YOUARENOTREGGED","Et ole rekisterity kyttj tai et ole kirjautunut sisn.");
define("_IFYOUWEREREG","Jos olisit rekisteritynyt, voisit kommetoida tt sivua.");
define("_WEBLINKS","Linkit");
define("_TITLE","Otsikko");
define("_MODIFY","Muokkaa");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
